:author: Austin Mroz

# STREUSEL
## Surface Topology REcovery Using Sampling of ELectric field

Overview
========
''STREUSEL'' is a comprehensive, generalized data analysis data analysis software suite used to assess atomic and molecular volumes, pore volumes and surface areas of porous materials, and interaction energetics.

Installation
============

''STREUSEL'' can be installed with pip::

    $ pip install streusel





